#!/bin/bash

CMD="$0"
MEMOPTS="-Xms2048M -Xmx4096M"

if [[ $CMD == *scripts* ]]; then
  # Script was run from non-scripts dir
  DEPLOY_DIR=`echo $CMD | sed 's/scripts\/start\.sh//'`
else
  # Script was run from scripts dir
  DEPLOY_DIR=".."
fi

if [ "$DEPLOY_DIR" != "" ]; then
  cd $DEPLOY_DIR
fi

export HORNETQ_HOME=`pwd`
# By default, the server is started in the non-clustered standalone configuration

CONFIG_DIR=cfg
FILENAME=hornetq-beans.xml

JAVA_OPTS="
-XX:-HeapDumpOnOutOfMemoryError
${MEMOPTS}
-Dcom.sun.management.jmxremote 
-Dcom.sun.management.jmxremote.authenticate=false
-Dcom.sun.management.jmxremote.ssl=false"

# Add additional system properties from the properties file
PROPERTIES=$CONFIG_DIR/local.properties
if [ -e $PROPERTIES ]; then
  while read line; do
    if [[ $line != \#* && $line != "" ]]; then
      JAVA_OPTS=$JAVA_OPTS" -D"$line
    fi  
  done < $PROPERTIES
fi

# Cleanup old STOP_ME file
if [ -e $CONFIG_DIR/STOP_ME ]; then
  rm $CONFIG_DIR/STOP_ME
fi

export CLASSPATH=$CONFIG_DIR:$HORNETQ_HOME/schemas/
export JVM_ARGS="$JAVA_OPTS $CLUSTER_PROPS -XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Dhornetq.config.dir=$CONFIG_DIR -Djava.util.logging.config.file=$CONFIG_DIR/logging.properties -Djava.library.path=../lib"

for i in `ls $HORNETQ_HOME/../lib/*.jar`; do
	CLASSPATH=$i:$CLASSPATH
done

echo "***********************************************************************************"
echo "java $JVM_ARGS -classpath $CLASSPATH org.hornetq.integration.bootstrap.HornetQBootstrapServer $FILENAME"
echo "***********************************************************************************"

java $JVM_ARGS -classpath $CLASSPATH -Dcom.sun.management.jmxremote org.hornetq.integration.bootstrap.HornetQBootstrapServer $FILENAME &
